# Pystega: Optimized Steganography Library

Pystega is a user-friendly Python library to hide some text into images (png, jpeg, jpg, ect.).

## Features

- Write data into an image
- Read data from an image

## Installation

You can install Pystega using pip:

```bash
pip install pystega